@@ -2,13 +2,14 @@
 
 # Load the data
 data_path <- system.file("extdata", "types_data.rds", package = "qtkit")
+
 data <- readRDS(data_path)
 
-test_that("calc_type_metrics returns expected output", {
+test_that("returns expected output", {
   result <- calc_type_metrics(
     data = data,
-    type = type,
-    document = document,
+    type = letter,
+    document = doc_id,
     frequency = c("rf", "orf"),
     dispersion = c("df", "idf", "dp")
   )
@@ -18,10 +19,10 @@ test_that("calc_type_metrics returns expected output", {
   expect_equal(ncol(result), 7) # type, n, rf, orf, df, idf, dp
 })
 
-test_that("calc_type_metrics handles invalid inputs", {
+test_that("handles invalid inputs", {
   expect_error(calc_type_metrics(data, "nonexistent", document))
-  expect_error(calc_type_metrics(data, type, "nonexistent"))
-  expect_error(calc_type_metrics("not a data frame", type, document))
-  expect_error(calc_type_metrics(data, type, document, "invalid"))
-  expect_error(calc_type_metrics(data, type, document, dispersion = "invalid"))
+  expect_error(calc_type_metrics(data, letters, "nonexistent"))
+  expect_error(calc_type_metrics("not a data frame", letters, doc_id))
+  expect_error(calc_type_metrics(data, letters, doc_id, "invalid"))
+  expect_error(calc_type_metrics(data, letters, doc_id, dispersion = "invalid"))
 })
